@@ -648,3 +648,21 @@ test!(
     "Thu Mar  5 23:51:47 2015"
     "#
 );
+
+test!(
+    sort_by_min_by_max_by,
+    r#"
+    sort_by(.a), sort_by(.a,.b), min_by(.a), min_by(.a,.b), max_by(.a), max_by(.a,.b)
+    "#,
+    r#"
+    [{"a":2,"b":3},{"a":0,"b":2},{"a":2,"b":2},{"a":0,"b":1},{"a":1,"b":1}]
+    "#,
+    r#"
+    [{"a":0,"b":2},{"a":0,"b":1},{"a":1,"b":1},{"a":2,"b":3},{"a":2,"b":2}]
+    [{"a":0,"b":1},{"a":0,"b":2},{"a":1,"b":1},{"a":2,"b":2},{"a":2,"b":3}]
+    {"a":0,"b":2}
+    {"a":0,"b":1}
+    {"a":2,"b":2}
+    {"a":2,"b":3}
+    "#
+);
